# Candango Cartola

[![Requirements Status](https://requires.io/github/candango/cartola/requirements.svg?branch=develop)](https://requires.io/github/candango/cartola/requirements/?branch=develop)

Candango's Shared Utilities.

Cartola means Top Hat. You see? A magician gets a rabbit from a Top Hat, right?
Right? I think you got the joke...

I'm pretty creative. ;)

We just needed a namespace to share some util modules, that's a great one.

## License

**Apache License V2.0**

Copyright © 2015-2021 Flavio Garcia
